@@ -1,6 +1,8 @@
+from ._by_animal_modifier import ByAnimalModifier
 from .default_behavior import DefaultBehaviorPicker, DefaultBehaviorPickerSettings
 
 __all__ = [
     "DefaultBehaviorPicker",
     "DefaultBehaviorPickerSettings",
+    "ByAnimalModifier",
 ]
