@@ -2,7 +2,7 @@ import glob
 import logging
 import os
 from pathlib import Path
-from typing import Callable, ClassVar, List, Optional, Type, Union
+from typing import Callable, ClassVar, List, Optional, Type, TypeVar, Union
 
 import pydantic
 from aind_behavior_curriculum import TrainerState
@@ -11,12 +11,15 @@ from aind_behavior_services.utils import model_from_json_file
 
 from .. import ui
 from .._typing import TRig, TSession, TTaskLogic
+from ..cache_manager import CacheManager
+from ..constants import ByAnimalFiles
 from ..launcher import Launcher
 from ..services import ServiceSettings
-from ..utils import ByAnimalFiles
 from ..utils.aind_auth import validate_aind_username
 
 logger = logging.getLogger(__name__)
+T = TypeVar("T")
+TInjectable = TypeVar("TInjectable")
 
 
 class DefaultBehaviorPickerSettings(ServiceSettings):
@@ -68,6 +71,7 @@ class DefaultBehaviorPicker:
         launcher: Launcher,
         ui_helper: Optional[ui.UiHelper] = None,
         experimenter_validator: Optional[Callable[[str], bool]] = validate_aind_username,
+        use_cache: bool = True,
     ):
         """
         Initializes the DefaultBehaviorPicker.
@@ -77,6 +81,7 @@ class DefaultBehaviorPicker:
             launcher: The launcher instance for managing experiment execution
             ui_helper: Helper for user interface interactions. If None, uses launcher's ui_helper. Defaults to None
             experimenter_validator: Function to validate the experimenter's username. If None, no validation is performed. Defaults to validate_aind_username
+            use_cache: Whether to use caching for selections. Defaults to True
         """
         self._launcher = launcher
         self._ui_helper = launcher.ui_helper if ui_helper is None else ui_helper
@@ -85,6 +90,8 @@ class DefaultBehaviorPicker:
         self._experimenter_validator = experimenter_validator
         self._trainer_state: Optional[TrainerState] = None
         self._session: Optional[AindBehaviorSessionModel] = None
+        self._cache_manager = CacheManager.get_instance()
+        self._use_cache = use_cache
 
     @property
     def ui_helper(self) -> ui.UiHelper:
@@ -116,6 +123,16 @@ class DefaultBehaviorPicker:
             raise ValueError("Trainer state not set.")
         return self._trainer_state
 
+    @property
+    def session_directory(self) -> Path:
+        """Returns the directory path for the current session."""
+        return self._launcher.session_directory
+
+    @property
+    def session(self) -> AindBehaviorSessionModel:
+        """Returns the current session model."""
+        return self._launcher.session
+
     @property
     def config_library_dir(self) -> Path:
         """
@@ -184,27 +201,60 @@ class DefaultBehaviorPicker:
         Raises:
             ValueError: If no rig configuration files are found or an invalid choice is made
         """
-        available_rigs = glob.glob(os.path.join(self.rig_dir, "*.json"))
-        if len(available_rigs) == 0:
-            logger.error("No rig config files found.")
-            raise ValueError("No rig config files found.")
-        elif len(available_rigs) == 1:
-            logger.info("Found a single rig config file. Using %s.", {available_rigs[0]})
-            rig = model_from_json_file(available_rigs[0], model)
-            return rig
+        rig: TRig | None = None
+        rig_path: str | None = None
+
+        # Check cache for previously used rigs
+        if self._use_cache:
+            cache = self._cache_manager.try_get_cache("rigs")
         else:
-            while True:
-                try:
-                    path = self.ui_helper.prompt_pick_from_list(available_rigs, prompt="Choose a rig:")
-                    if not isinstance(path, str):
-                        raise ValueError("Invalid choice.")
-                    rig = model_from_json_file(path, model)
-                    logger.info("Using %s.", path)
-                    return rig
-                except pydantic.ValidationError as e:
-                    logger.error("Failed to validate pydantic model. Try again. %s", e)
-                except ValueError as e:
-                    logger.info("Invalid choice. Try again. %s", e)
+            cache = None
+
+        if cache:
+            cache.sort()
+            rig_path = self.ui_helper.prompt_pick_from_list(
+                cache,
+                prompt="Choose a rig:",
+                allow_0_as_none=True,
+                zero_label="Select from library",
+            )
+            if rig_path is not None:
+                rig = self._load_rig_from_path(Path(rig_path), model)
+
+        # Prompt user to select a rig if not already selected
+        while rig_path is None:
+            available_rigs = glob.glob(os.path.join(self.rig_dir, "*.json"))
+            # We raise if no rigs are found to prevent an infinite loop
+            if len(available_rigs) == 0:
+                logger.error("No rig config files found.")
+                raise ValueError("No rig config files found.")
+            # Use the single available rig config file
+            elif len(available_rigs) == 1:
+                logger.info("Found a single rig config file. Using %s.", {available_rigs[0]})
+                rig_path = available_rigs[0]
+                rig = model_from_json_file(rig_path, model)
+            else:
+                rig_path = self.ui_helper.prompt_pick_from_list(available_rigs, prompt="Choose a rig:")
+                if rig_path is not None:
+                    rig = self._load_rig_from_path(Path(rig_path), model)
+        assert rig_path is not None
+        assert rig is not None
+        # Add the selected rig path to the cache
+        self._cache_manager.add_to_cache("rigs", rig_path)
+        return rig
+
+    @staticmethod
+    def _load_rig_from_path(path: Path, model: Type[TRig]) -> TRig | None:
+        """Load a rig configuration from a given path."""
+        try:
+            rig = model_from_json_file(path, model)
+            logger.info("Using %s.", path)
+            return rig
+        except pydantic.ValidationError as e:
+            logger.error("Failed to validate pydantic model. Try again. %s", e)
+        except ValueError as e:
+            logger.info("Invalid choice. Try again. %s", e)
+        return None
 
     def pick_session(self, model: Type[TSession] = AindBehaviorSessionModel) -> TSession:
         """
@@ -366,22 +416,26 @@ class DefaultBehaviorPicker:
             subject = picker.choose_subject("Subjects")
             ```
         """
-        subject = None
+        if self._use_cache:
+            subjects = self._cache_manager.try_get_cache("subjects")
+        else:
+            subjects = None
+        if subjects:
+            subjects.sort()
+            subject = self.ui_helper.prompt_pick_from_list(
+                subjects,
+                prompt="Choose a subject:",
+                allow_0_as_none=True,
+                zero_label="Enter manually",
+            )
+        else:
+            subject = None
+
         while subject is None:
             subject = self.ui_helper.input("Enter subject name: ")
             if subject == "":
-                subject = self.ui_helper.prompt_pick_from_list(
-                    [
-                        os.path.basename(folder)
-                        for folder in os.listdir(directory)
-                        if os.path.isdir(os.path.join(directory, folder))
-                    ],
-                    prompt="Choose a subject:",
-                    allow_0_as_none=True,
-                )
-            else:
-                return subject
-
+                subject = None
+        self._cache_manager.add_to_cache("subjects", subject)
         return subject
 
     def prompt_experimenter(self, strict: bool = True) -> Optional[List[str]]:
@@ -404,10 +458,26 @@ class DefaultBehaviorPicker:
             print("Experimenters:", names)
             ```
         """
+        if self._use_cache:
+            experimenters_cache = self._cache_manager.try_get_cache("experimenters")
+        else:
+            experimenters_cache = None
         experimenter: Optional[List[str]] = None
+        _picked: str | None = None
         while experimenter is None:
-            _user_input = self.ui_helper.prompt_text("Experimenter name: ")
-            experimenter = _user_input.replace(",", " ").split()
+            if experimenters_cache:
+                experimenters_cache.sort()
+                _picked = self.ui_helper.prompt_pick_from_list(
+                    experimenters_cache,
+                    prompt="Choose an experimenter:",
+                    allow_0_as_none=True,
+                    zero_label="Enter manually",
+                )
+            if _picked is None:
+                _input = self.ui_helper.prompt_text("Experimenter name: ")
+            else:
+                _input = _picked
+            experimenter = _input.replace(",", " ").split()
             if strict & (len(experimenter) == 0):
                 logger.info("Experimenter name is not valid. Try again.")
                 experimenter = None
@@ -418,6 +488,7 @@ class DefaultBehaviorPicker:
                             logger.warning("Experimenter name: %s, is not valid. Try again", name)
                             experimenter = None
                             break
+        self._cache_manager.add_to_cache("experimenters", ",".join(experimenter))
         return experimenter
 
     def dump_model(
